@@ -21,13 +21,13 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-#include "test.h"
+#include "first.h"
 
 #include "memdebug.h"
 
 /* Test CURLINFO_PROTOCOL */
 
-CURLcode test(char *URL)
+static CURLcode test_lib1535(char *URL)
 {
   CURL *curl, *dupe = NULL;
   long protocol;
@@ -113,7 +113,6 @@ CURLcode test(char *URL)
     goto test_cleanup;
   }
 
-
   /* Test that a protocol is properly initialized on curl_easy_reset.
   */
 
