@@ -21,26 +21,19 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-#include "test.h"
+#include "first.h"
 
-#ifdef HAVE_SYS_RESOURCE_H
-#include <sys/resource.h>
-#endif
-#ifdef HAVE_FCNTL_H
-#include <fcntl.h>
-#endif
-#include <limits.h>
-
-#include "warnless.h"
+#include "testutil.h"
 #include "memdebug.h"
 
 #ifndef FD_SETSIZE
 #error "this test requires FD_SETSIZE"
 #endif
 
-#define SAFETY_MARGIN (16)
+#define T518_SAFETY_MARGIN (16)
+
 #define NUM_OPEN      (FD_SETSIZE + 10)
-#define NUM_NEEDED    (NUM_OPEN + SAFETY_MARGIN)
+#define NUM_NEEDED    (NUM_OPEN + T518_SAFETY_MARGIN)
 
 #if defined(_WIN32) || defined(MSDOS)
 #define DEV_NULL "NUL"
@@ -50,31 +43,31 @@
 
 #if defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT)
 
-static int *testfd = NULL;
-static struct rlimit num_open;
-static char msgbuff[256];
+static int *t518_testfd = NULL;
+static struct rlimit t518_num_open;
+static char t518_msgbuff[256];
 
-static void store_errmsg(const char *msg, int err)
+static void t518_store_errmsg(const char *msg, int err)
 {
   if(!err)
-    curl_msnprintf(msgbuff, sizeof(msgbuff), "%s", msg);
+    curl_msnprintf(t518_msgbuff, sizeof(t518_msgbuff), "%s", msg);
   else
-    curl_msnprintf(msgbuff, sizeof(msgbuff), "%s, errno %d, %s", msg,
-              err, strerror(err));
+    curl_msnprintf(t518_msgbuff, sizeof(t518_msgbuff), "%s, errno %d, %s", msg,
+                   err, strerror(err));
 }
 
-static void close_file_descriptors(void)
+static void t518_close_file_descriptors(void)
 {
-  for(num_open.rlim_cur = 0;
-      num_open.rlim_cur < num_open.rlim_max;
-      num_open.rlim_cur++)
-    if(testfd[num_open.rlim_cur] > 0)
-      close(testfd[num_open.rlim_cur]);
-  free(testfd);
-  testfd = NULL;
+  for(t518_num_open.rlim_cur = 0;
+      t518_num_open.rlim_cur < t518_num_open.rlim_max;
+      t518_num_open.rlim_cur++)
+    if(t518_testfd[t518_num_open.rlim_cur] > 0)
+      close(t518_testfd[t518_num_open.rlim_cur]);
+  free(t518_testfd);
+  t518_testfd = NULL;
 }
 
-static int fopen_works(void)
+static int t518_fopen_works(void)
 {
   FILE *fpa[3];
   int i;
@@ -86,8 +79,8 @@ static int fopen_works(void)
   for(i = 0; i < 3; i++) {
     fpa[i] = fopen(DEV_NULL, FOPEN_READTEXT);
     if(!fpa[i]) {
-      store_errmsg("fopen failed", errno);
-      curl_mfprintf(stderr, "%s\n", msgbuff);
+      t518_store_errmsg("fopen failed", errno);
+      curl_mfprintf(stderr, "%s\n", t518_msgbuff);
       ret = 0;
       break;
     }
@@ -99,28 +92,7 @@ static int fopen_works(void)
   return ret;
 }
 
-static void rlim2str(char *buf, size_t len, rlim_t val)
-{
-#ifdef RLIM_INFINITY
-  if(val == RLIM_INFINITY) {
-    curl_msnprintf(buf, len, "INFINITY");
-    return;
-  }
-#endif
-#ifdef HAVE_LONGLONG
-  if(sizeof(rlim_t) > sizeof(long))
-    curl_msnprintf(buf, len, "%llu", (unsigned long long)val);
-  else
-#endif
-  {
-    if(sizeof(rlim_t) < sizeof(long))
-      curl_msnprintf(buf, len, "%u", (unsigned int)val);
-    else
-      curl_msnprintf(buf, len, "%lu", (unsigned long)val);
-  }
-}
-
-static int test_rlimit(int keep_open)
+static int t518_test_rlimit(int keep_open)
 {
   rlim_t nitems, i;
   int *memchunk = NULL;
@@ -132,17 +104,17 @@ static int test_rlimit(int keep_open)
   /* get initial open file limits */
 
   if(getrlimit(RLIMIT_NOFILE, &rl) != 0) {
-    store_errmsg("getrlimit() failed", errno);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
+    t518_store_errmsg("getrlimit() failed", errno);
+    curl_mfprintf(stderr, "%s\n", t518_msgbuff);
     return -1;
   }
 
   /* show initial open file limits */
 
-  rlim2str(strbuff, sizeof(strbuff), rl.rlim_cur);
+  tutil_rlim2str(strbuff, sizeof(strbuff), rl.rlim_cur);
   curl_mfprintf(stderr, "initial soft limit: %s\n", strbuff);
 
-  rlim2str(strbuff, sizeof(strbuff), rl.rlim_max);
+  tutil_rlim2str(strbuff, sizeof(strbuff), rl.rlim_max);
   curl_mfprintf(stderr, "initial hard limit: %s\n", strbuff);
 
   /* show our constants */
@@ -169,9 +141,9 @@ static int test_rlimit(int keep_open)
       rl.rlim_cur = OPEN_MAX;
       if(setrlimit(RLIMIT_NOFILE, &rl) != 0) {
         /* on failure don't abort just issue a warning */
-        store_errmsg("setrlimit() failed", errno);
-        curl_mfprintf(stderr, "%s\n", msgbuff);
-        msgbuff[0] = '\0';
+        t518_store_errmsg("setrlimit() failed", errno);
+        curl_mfprintf(stderr, "%s\n", t518_msgbuff);
+        t518_msgbuff[0] = '\0';
       }
     }
 #endif
@@ -180,25 +152,25 @@ static int test_rlimit(int keep_open)
     rl.rlim_cur = rl.rlim_max;
     if(setrlimit(RLIMIT_NOFILE, &rl) != 0) {
       /* on failure don't abort just issue a warning */
-      store_errmsg("setrlimit() failed", errno);
-      curl_mfprintf(stderr, "%s\n", msgbuff);
-      msgbuff[0] = '\0';
+      t518_store_errmsg("setrlimit() failed", errno);
+      curl_mfprintf(stderr, "%s\n", t518_msgbuff);
+      t518_msgbuff[0] = '\0';
     }
 
     /* get current open file limits */
 
     if(getrlimit(RLIMIT_NOFILE, &rl) != 0) {
-      store_errmsg("getrlimit() failed", errno);
-      curl_mfprintf(stderr, "%s\n", msgbuff);
+      t518_store_errmsg("getrlimit() failed", errno);
+      curl_mfprintf(stderr, "%s\n", t518_msgbuff);
       return -3;
     }
 
     /* show current open file limits */
 
-    rlim2str(strbuff, sizeof(strbuff), rl.rlim_cur);
+    tutil_rlim2str(strbuff, sizeof(strbuff), rl.rlim_cur);
     curl_mfprintf(stderr, "current soft limit: %s\n", strbuff);
 
-    rlim2str(strbuff, sizeof(strbuff), rl.rlim_max);
+    tutil_rlim2str(strbuff, sizeof(strbuff), rl.rlim_max);
     curl_mfprintf(stderr, "current hard limit: %s\n", strbuff);
 
   } /* (rl.rlim_cur != rl.rlim_max) */
@@ -214,23 +186,23 @@ static int test_rlimit(int keep_open)
   /*
    * verify that soft limit is higher than NUM_NEEDED,
    * which is the number of file descriptors we would
-   * try to open plus SAFETY_MARGIN to not exhaust the
+   * try to open plus T518_SAFETY_MARGIN to not exhaust the
    * file descriptor pool
    */
 
-  num_open.rlim_cur = NUM_NEEDED;
+  t518_num_open.rlim_cur = NUM_NEEDED;
 
   if((rl.rlim_cur > 0) &&
 #ifdef RLIM_INFINITY
      (rl.rlim_cur != RLIM_INFINITY) &&
 #endif
-     (rl.rlim_cur <= num_open.rlim_cur)) {
-    rlim2str(strbuff2, sizeof(strbuff2), rl.rlim_cur);
-    rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_cur);
+     (rl.rlim_cur <= t518_num_open.rlim_cur)) {
+    tutil_rlim2str(strbuff2, sizeof(strbuff2), rl.rlim_cur);
+    tutil_rlim2str(strbuff1, sizeof(strbuff1), t518_num_open.rlim_cur);
     curl_msnprintf(strbuff, sizeof(strbuff), "fds needed %s > system limit %s",
-              strbuff1, strbuff2);
-    store_errmsg(strbuff, 0);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
+                   strbuff1, strbuff2);
+    t518_store_errmsg(strbuff, 0);
+    curl_mfprintf(stderr, "%s\n", t518_msgbuff);
     return -4;
   }
 
@@ -239,7 +211,7 @@ static int test_rlimit(int keep_open)
    * avoid a low memory condition once the file descriptors are
    * open. System conditions that could make the test fail should
    * be addressed in the precheck phase. This chunk of memory shall
-   * be always free()ed before exiting the test_rlimit() function so
+   * be always free()ed before exiting the t518_test_rlimit() function so
    * that it becomes available to the test.
    */
 
@@ -248,8 +220,8 @@ static int test_rlimit(int keep_open)
   if(nitems > 0x7fff)
     nitems = 0x40000;
   do {
-    num_open.rlim_max = sizeof(*memchunk) * nitems;
-    rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
+    t518_num_open.rlim_max = sizeof(*memchunk) * nitems;
+    tutil_rlim2str(strbuff, sizeof(strbuff), t518_num_open.rlim_max);
     curl_mfprintf(stderr, "allocating memchunk %s byte array\n", strbuff);
     memchunk = malloc(sizeof(*memchunk) * (size_t)nitems);
     if(!memchunk) {
@@ -258,8 +230,8 @@ static int test_rlimit(int keep_open)
     }
   } while(nitems && !memchunk);
   if(!memchunk) {
-    store_errmsg("memchunk, malloc() failed", errno);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
+    t518_store_errmsg("memchunk, malloc() failed", errno);
+    curl_mfprintf(stderr, "%s\n", t518_msgbuff);
     return -5;
   }
 
@@ -272,30 +244,31 @@ static int test_rlimit(int keep_open)
 
   /* set the number of file descriptors we will try to open */
 
-  num_open.rlim_max = NUM_OPEN;
+  t518_num_open.rlim_max = NUM_OPEN;
 
   /* verify that we won't overflow size_t in malloc() */
 
-  if((size_t)(num_open.rlim_max) > ((size_t)-1) / sizeof(*testfd)) {
-    rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_max);
+  if((size_t)(t518_num_open.rlim_max) > ((size_t)-1) / sizeof(*t518_testfd)) {
+    tutil_rlim2str(strbuff1, sizeof(strbuff1), t518_num_open.rlim_max);
     curl_msnprintf(strbuff, sizeof(strbuff),
                    "unable to allocate an array for %s "
                    "file descriptors, would overflow size_t", strbuff1);
-    store_errmsg(strbuff, 0);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
+    t518_store_errmsg(strbuff, 0);
+    curl_mfprintf(stderr, "%s\n", t518_msgbuff);
     free(memchunk);
     return -6;
   }
 
   /* allocate array for file descriptors */
 
-  rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
+  tutil_rlim2str(strbuff, sizeof(strbuff), t518_num_open.rlim_max);
   curl_mfprintf(stderr, "allocating array for %s file descriptors\n", strbuff);
 
-  testfd = malloc(sizeof(*testfd) * (size_t)(num_open.rlim_max));
-  if(!testfd) {
-    store_errmsg("testfd, malloc() failed", errno);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
+  t518_testfd = malloc(sizeof(*t518_testfd) *
+                       (size_t)(t518_num_open.rlim_max));
+  if(!t518_testfd) {
+    t518_store_errmsg("testfd, malloc() failed", errno);
+    curl_mfprintf(stderr, "%s\n", t518_msgbuff);
     free(memchunk);
     return -7;
   }
@@ -304,70 +277,70 @@ static int test_rlimit(int keep_open)
 
   curl_mfprintf(stderr, "initializing testfd array\n");
 
-  for(num_open.rlim_cur = 0;
-      num_open.rlim_cur < num_open.rlim_max;
-      num_open.rlim_cur++)
-    testfd[num_open.rlim_cur] = -1;
+  for(t518_num_open.rlim_cur = 0;
+      t518_num_open.rlim_cur < t518_num_open.rlim_max;
+      t518_num_open.rlim_cur++)
+    t518_testfd[t518_num_open.rlim_cur] = -1;
 
-  rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
+  tutil_rlim2str(strbuff, sizeof(strbuff), t518_num_open.rlim_max);
   curl_mfprintf(stderr, "trying to open %s file descriptors\n", strbuff);
 
   /* open a dummy descriptor */
 
-  testfd[0] = open(DEV_NULL, O_RDONLY);
-  if(testfd[0] < 0) {
+  t518_testfd[0] = open(DEV_NULL, O_RDONLY);
+  if(t518_testfd[0] < 0) {
     curl_msnprintf(strbuff, sizeof(strbuff), "opening of %s failed", DEV_NULL);
-    store_errmsg(strbuff, errno);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
-    free(testfd);
-    testfd = NULL;
+    t518_store_errmsg(strbuff, errno);
+    curl_mfprintf(stderr, "%s\n", t518_msgbuff);
+    free(t518_testfd);
+    t518_testfd = NULL;
     free(memchunk);
     return -8;
   }
 
   /* create a bunch of file descriptors */
 
-  for(num_open.rlim_cur = 1;
-      num_open.rlim_cur < num_open.rlim_max;
-      num_open.rlim_cur++) {
+  for(t518_num_open.rlim_cur = 1;
+      t518_num_open.rlim_cur < t518_num_open.rlim_max;
+      t518_num_open.rlim_cur++) {
 
-    testfd[num_open.rlim_cur] = dup(testfd[0]);
+    t518_testfd[t518_num_open.rlim_cur] = dup(t518_testfd[0]);
 
-    if(testfd[num_open.rlim_cur] < 0) {
+    if(t518_testfd[t518_num_open.rlim_cur] < 0) {
 
-      testfd[num_open.rlim_cur] = -1;
+      t518_testfd[t518_num_open.rlim_cur] = -1;
 
-      rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_cur);
+      tutil_rlim2str(strbuff1, sizeof(strbuff1), t518_num_open.rlim_cur);
       curl_msnprintf(strbuff, sizeof(strbuff), "dup() attempt %s failed",
                      strbuff1);
       curl_mfprintf(stderr, "%s\n", strbuff);
 
-      rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_cur);
+      tutil_rlim2str(strbuff1, sizeof(strbuff1), t518_num_open.rlim_cur);
       curl_msnprintf(strbuff, sizeof(strbuff),
                      "fds system limit seems close to %s", strbuff1);
       curl_mfprintf(stderr, "%s\n", strbuff);
 
-      num_open.rlim_max = NUM_NEEDED;
+      t518_num_open.rlim_max = NUM_NEEDED;
 
-      rlim2str(strbuff2, sizeof(strbuff2), num_open.rlim_max);
-      rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_cur);
+      tutil_rlim2str(strbuff2, sizeof(strbuff2), t518_num_open.rlim_max);
+      tutil_rlim2str(strbuff1, sizeof(strbuff1), t518_num_open.rlim_cur);
       curl_msnprintf(strbuff, sizeof(strbuff),
                      "fds needed %s > system limit %s", strbuff2, strbuff1);
-      store_errmsg(strbuff, 0);
-      curl_mfprintf(stderr, "%s\n", msgbuff);
+      t518_store_errmsg(strbuff, 0);
+      curl_mfprintf(stderr, "%s\n", t518_msgbuff);
 
-      for(num_open.rlim_cur = 0;
-          testfd[num_open.rlim_cur] >= 0;
-          num_open.rlim_cur++)
-        close(testfd[num_open.rlim_cur]);
-      free(testfd);
-      testfd = NULL;
+      for(t518_num_open.rlim_cur = 0;
+          t518_testfd[t518_num_open.rlim_cur] >= 0;
+          t518_num_open.rlim_cur++)
+        close(t518_testfd[t518_num_open.rlim_cur]);
+      free(t518_testfd);
+      t518_testfd = NULL;
       free(memchunk);
       return -9;
     }
   }
 
-  rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
+  tutil_rlim2str(strbuff, sizeof(strbuff), t518_num_open.rlim_max);
   curl_mfprintf(stderr, "%s file descriptors open\n", strbuff);
 
 #if !defined(HAVE_POLL) && !defined(USE_WINSOCK)
@@ -383,34 +356,34 @@ static int test_rlimit(int keep_open)
    * with an indication that select limit would be exceeded.
    */
 
-  num_open.rlim_cur = FD_SETSIZE - SAFETY_MARGIN;
-  if(num_open.rlim_max > num_open.rlim_cur) {
+  t518_num_open.rlim_cur = FD_SETSIZE - T518_SAFETY_MARGIN;
+  if(t518_num_open.rlim_max > t518_num_open.rlim_cur) {
     curl_msnprintf(strbuff, sizeof(strbuff), "select limit is FD_SETSIZE %d",
-              FD_SETSIZE);
-    store_errmsg(strbuff, 0);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
-    close_file_descriptors();
+                   FD_SETSIZE);
+    t518_store_errmsg(strbuff, 0);
+    curl_mfprintf(stderr, "%s\n", t518_msgbuff);
+    t518_close_file_descriptors();
     free(memchunk);
     return -10;
   }
 
-  num_open.rlim_cur = FD_SETSIZE - SAFETY_MARGIN;
+  t518_num_open.rlim_cur = FD_SETSIZE - T518_SAFETY_MARGIN;
   for(rl.rlim_cur = 0;
-      rl.rlim_cur < num_open.rlim_max;
+      rl.rlim_cur < t518_num_open.rlim_max;
       rl.rlim_cur++) {
-    if((testfd[rl.rlim_cur] > 0) &&
-       ((unsigned int)testfd[rl.rlim_cur] > num_open.rlim_cur)) {
+    if((t518_testfd[rl.rlim_cur] > 0) &&
+       ((unsigned int)t518_testfd[rl.rlim_cur] > t518_num_open.rlim_cur)) {
       curl_msnprintf(strbuff, sizeof(strbuff), "select limit is FD_SETSIZE %d",
-                FD_SETSIZE);
-      store_errmsg(strbuff, 0);
-      curl_mfprintf(stderr, "%s\n", msgbuff);
-      close_file_descriptors();
+                     FD_SETSIZE);
+      t518_store_errmsg(strbuff, 0);
+      curl_mfprintf(stderr, "%s\n", t518_msgbuff);
+      t518_close_file_descriptors();
       free(memchunk);
       return -11;
     }
   }
 
-#endif /* using a FD_SETSIZE bound select() */
+#endif /* using an FD_SETSIZE bound select() */
 
   /*
    * Old or 'backwards compatible' implementations of stdio do not allow
@@ -421,15 +394,15 @@ static int test_rlimit(int keep_open)
    * if it is capable of fopen()ing some additional files.
    */
 
-  if(!fopen_works()) {
-    rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_max);
+  if(!t518_fopen_works()) {
+    tutil_rlim2str(strbuff1, sizeof(strbuff1), t518_num_open.rlim_max);
     curl_msnprintf(strbuff, sizeof(strbuff), "fopen fails with %s fds open",
-              strbuff1);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
+                   strbuff1);
+    curl_mfprintf(stderr, "%s\n", t518_msgbuff);
     curl_msnprintf(strbuff, sizeof(strbuff),
                    "fopen fails with lots of fds open");
-    store_errmsg(strbuff, 0);
-    close_file_descriptors();
+    t518_store_errmsg(strbuff, 0);
+    t518_close_file_descriptors();
     free(memchunk);
     return -12;
   }
@@ -442,27 +415,27 @@ static int test_rlimit(int keep_open)
   /* close file descriptors unless instructed to keep them */
 
   if(!keep_open) {
-    close_file_descriptors();
+    t518_close_file_descriptors();
   }
 
   return 0;
 }
 
-CURLcode test(char *URL)
+static CURLcode test_lib518(char *URL)
 {
   CURLcode res;
   CURL *curl;
 
   if(!strcmp(URL, "check")) {
     /* used by the test script to ask if we can run this test or not */
-    if(test_rlimit(FALSE)) {
-      curl_mfprintf(stdout, "test_rlimit problem: %s\n", msgbuff);
+    if(t518_test_rlimit(FALSE)) {
+      curl_mfprintf(stdout, "test_rlimit problem: %s\n", t518_msgbuff);
       return TEST_ERR_FAILURE;
     }
     return CURLE_OK; /* sure, run this! */
   }
 
-  if(test_rlimit(TRUE)) {
+  if(t518_test_rlimit(TRUE)) {
     /* failure */
     return TEST_ERR_MAJOR_BAD;
   }
@@ -472,14 +445,14 @@ CURLcode test(char *URL)
 
   if(curl_global_init(CURL_GLOBAL_ALL) != CURLE_OK) {
     curl_mfprintf(stderr, "curl_global_init() failed\n");
-    close_file_descriptors();
+    t518_close_file_descriptors();
     return TEST_ERR_MAJOR_BAD;
   }
 
   curl = curl_easy_init();
   if(!curl) {
     curl_mfprintf(stderr, "curl_easy_init() failed\n");
-    close_file_descriptors();
+    t518_close_file_descriptors();
     curl_global_cleanup();
     return TEST_ERR_MAJOR_BAD;
   }
@@ -491,7 +464,7 @@ CURLcode test(char *URL)
 
 test_cleanup:
 
-  close_file_descriptors();
+  t518_close_file_descriptors();
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
@@ -500,11 +473,11 @@ test_cleanup:
 
 #else /* defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT) */
 
-CURLcode test(char *URL)
+static CURLcode test_lib518(char *URL)
 {
   (void)URL;
   curl_mprintf("system lacks necessary system function(s)");
-  return 1; /* skip test */
+  return TEST_ERR_MAJOR_BAD; /* skip test */
 }
 
 #endif /* defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT) */
