@@ -27,49 +27,41 @@
  * sharing within the multi handle all transfers are performed on the same
  * persistent connection.
  *
- * This source code is used for lib526, lib527 and lib532 with only #ifdefs
+ * This source code is used for test526, test527 and test532 with branches
  * controlling the small differences.
  *
- * - lib526 closes all easy handles after
+ * - test526 closes all easy handles after
  *   they all have transferred the file over the single connection
- * - lib527 closes each easy handle after each single transfer.
- * - lib532 uses only a single easy handle that is removed, reset and then
+ * - test527 closes each easy handle after each single transfer.
+ * - test532 uses only a single easy handle that is removed, reset and then
  *   re-added for each transfer
  *
  * Test case 526, 527 and 532 use FTP, while test 528 uses the lib526 tool but
  * with HTTP.
  */
 
-#include "test.h"
+#include "first.h"
 
-#include <fcntl.h>
-
-#include "testutil.h"
-#include "warnless.h"
 #include "memdebug.h"
 
-#define TEST_HANG_TIMEOUT 60 * 1000
-
-#define NUM_HANDLES 4
-
-int test(char *URL)
+static CURLcode test_lib526(char *URL)
 {
-  int res = 0;
+  CURLcode res = CURLE_OK;
   CURL *curl[NUM_HANDLES];
   int running;
   CURLM *m = NULL;
-  int current = 0;
-  int i;
+  size_t current = 0;
+  size_t i;
 
-  for(i = 0; i < NUM_HANDLES; i++)
+  for(i = 0; i < CURL_ARRAYSIZE(curl); i++)
     curl[i] = NULL;
 
   start_test_timing();
 
   global_init(CURL_GLOBAL_ALL);
 
-  /* get NUM_HANDLES easy handles */
-  for(i = 0; i < NUM_HANDLES; i++) {
+  /* get each easy handle */
+  for(i = 0; i < CURL_ARRAYSIZE(curl); i++) {
     easy_init(curl[i]);
     /* specify target */
     easy_setopt(curl[i], CURLOPT_URL, URL);
@@ -81,7 +73,7 @@ int test(char *URL)
 
   multi_add_handle(m, curl[current]);
 
-  fprintf(stderr, "Start at URL 0\n");
+  curl_mfprintf(stderr, "Start at URL 0\n");
 
   for(;;) {
     struct timeval interval;
@@ -96,31 +88,32 @@ int test(char *URL)
     abort_on_test_timeout();
 
     if(!running) {
-#ifdef LIB527
-      /* NOTE: this code does not remove the handle from the multi handle
-         here, which would be the nice, sane and documented way of working.
-         This however tests that the API survives this abuse gracefully. */
-      curl_easy_cleanup(curl[current]);
-      curl[current] = NULL;
-#endif
-      if(++current < NUM_HANDLES) {
-        fprintf(stderr, "Advancing to URL %d\n", current);
-#ifdef LIB532
-        /* first remove the only handle we use */
-        curl_multi_remove_handle(m, curl[0]);
+      if(testnum == 527) {
+        /* NOTE: this code does not remove the handle from the multi handle
+           here, which would be the nice, sane and documented way of working.
+           This however tests that the API survives this abuse gracefully. */
+        curl_easy_cleanup(curl[current]);
+        curl[current] = NULL;
+      }
+      if(++current < CURL_ARRAYSIZE(curl)) {
+        curl_mfprintf(stderr, "Advancing to URL %d\n", (int)current);
+        if(testnum == 532) {
+          /* first remove the only handle we use */
+          curl_multi_remove_handle(m, curl[0]);
 
-        /* make us reuse the same handle all the time, and try resetting
-           the handle first too */
-        curl_easy_reset(curl[0]);
-        easy_setopt(curl[0], CURLOPT_URL, URL);
-        /* go verbose */
-        easy_setopt(curl[0], CURLOPT_VERBOSE, 1L);
+          /* make us reuse the same handle all the time, and try resetting
+             the handle first too */
+          curl_easy_reset(curl[0]);
+          easy_setopt(curl[0], CURLOPT_URL, URL);
+          /* go verbose */
+          easy_setopt(curl[0], CURLOPT_VERBOSE, 1L);
 
-        /* re-add it */
-        multi_add_handle(m, curl[0]);
-#else
-        multi_add_handle(m, curl[current]);
-#endif
+          /* re-add it */
+          multi_add_handle(m, curl[0]);
+        }
+        else {
+          multi_add_handle(m, curl[current]);
+        }
       }
       else {
         break; /* done */
@@ -142,45 +135,38 @@ int test(char *URL)
 
 test_cleanup:
 
-#if defined(LIB526)
+  if((testnum == 526) || (testnum == 528)) {
+    /* proper cleanup sequence - type PB */
 
-  /* test 526 and 528 */
-  /* proper cleanup sequence - type PB */
-
-  for(i = 0; i < NUM_HANDLES; i++) {
-    curl_multi_remove_handle(m, curl[i]);
-    curl_easy_cleanup(curl[i]);
-  }
-  curl_multi_cleanup(m);
-  curl_global_cleanup();
-
-#elif defined(LIB527)
-
-  /* test 527 */
-
-  /* Upon non-failure test flow the easy's have already been cleanup'ed. In
-     case there is a failure we arrive here with easy's that have not been
-     cleanup'ed yet, in this case we have to cleanup them or otherwise these
-     will be leaked, let's use undocumented cleanup sequence - type UB */
-
-  if(res)
-    for(i = 0; i < NUM_HANDLES; i++)
+    for(i = 0; i < CURL_ARRAYSIZE(curl); i++) {
+      curl_multi_remove_handle(m, curl[i]);
       curl_easy_cleanup(curl[i]);
+    }
+    curl_multi_cleanup(m);
+    curl_global_cleanup();
+  }
+  else if(testnum == 527) {
+    /* Upon non-failure test flow the easy's have already been cleanup'ed. In
+       case there is a failure we arrive here with easy's that have not been
+       cleanup'ed yet, in this case we have to cleanup them or otherwise these
+       will be leaked, let's use undocumented cleanup sequence - type UB */
 
-  curl_multi_cleanup(m);
-  curl_global_cleanup();
+    if(res != CURLE_OK)
+      for(i = 0; i < CURL_ARRAYSIZE(curl); i++)
+        curl_easy_cleanup(curl[i]);
 
-#elif defined(LIB532)
+    curl_multi_cleanup(m);
+    curl_global_cleanup();
 
-  /* test 532 */
-  /* undocumented cleanup sequence - type UB */
+  }
+  else if(testnum == 532) {
+    /* undocumented cleanup sequence - type UB */
 
-  for(i = 0; i < NUM_HANDLES; i++)
-    curl_easy_cleanup(curl[i]);
-  curl_multi_cleanup(m);
-  curl_global_cleanup();
-
-#endif
+    for(i = 0; i < CURL_ARRAYSIZE(curl); i++)
+      curl_easy_cleanup(curl[i]);
+    curl_multi_cleanup(m);
+    curl_global_cleanup();
+  }
 
   return res;
 }
